==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/admin/messages/uz/settings.php <==
<?php

return [
    'User' => 'Foydalanuvchi',
    '"My Spaces" Sorting' => '',
    '1 month' => '',
    '1 week' => '',
    '1 year' => '',
    '2 weeks' => '',
    '3 months' => '',
    '6 months' => '',
    '<strong>Confirm</strong> icon deletion' => '',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Confirm</strong> topic deletion' => '',
    'APC(u)' => '',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Add OEmbed provider' => '',
    'Add Topic' => '',
    'Add custom info text for maintenance mode. Displayed on the login page.' => '',
    'Add individual info text...' => '',
    'Add new provider' => '',
    'Advanced Settings' => '',
    'Allow Self-Signed Certificates?' => '',
    'Allowed file extensions' => '',
    'Appearance Settings' => '',
    'Auto format based on user language - Example: {example}' => '',
    'Back to overview' => '',
    'Base URL' => '',
    'Cache Backend' => '',
    'Comma separated list. Leave empty to allow all.' => '',
    'Configuration (Use settings from configuration file)' => '',
    'Convert to global topic' => '',
    'Could not send test email.' => '',
    'Currently no provider active!' => '',
    'Currently there are {count} records in the database dating from {dating}.' => '',
    'Custom DSN' => '',
    'Custom sort order (alphabetical if not defined)' => '',
    'Custom sort order can be defined in the Space advanced settings.' => '',
    'DSN' => '',
    'DSN Examples:' => '',
    'Dashboard' => '',
    'Date input format' => '',
    'Default Expire Time (in seconds)' => '',
    'Default Timezone' => '',
    'Default language' => '',
    'Default pagination size (Entries per page)' => '',
    'Default stream content order' => '',
    'Delete' => '',
    'Do you really want to delete this topic?' => '',
    'E-Mail' => '',
    'E-Mail reply-to' => '',
    'E-Mail sender address' => '',
    'E-Mail sender name' => '',
    'E.g. http://example.com/humhub' => '',
    'Edit OEmbed provider' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Enable maintenance mode' => '',
    'Enable user friendship system' => '',
    'Enabled' => '',
    'Enabled OEmbed providers' => '',
    'Endpoint Url' => '',
    'Exclude media files from stream attachment list' => '',
    'File' => '',
    'Firstname Lastname (e.g. John Doe)' => '',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => '',
    'Friendship' => '',
    'General' => '',
    'General Settings' => '',
    'Global topics can be used by all users in all Spaces. They make it easier for you to define consistent keywords throughout your entire network. If users have already created topics in Spaces, you can also convert them to global topics here.' => '',
    'HTML tracking code' => '',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => '',
    'Here you can configure basic settings of your social network.' => '',
    'Horizontal scrolling images on a mobile device' => '',
    'Icon upload' => '',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
    'Last visit' => '',
    'Logo upload' => '',
    'Mail Transport Type' => '',
    'Maintenance mode' => '',
    'Maintenance mode restricts access to the platform and immediately logs out all users except Admins.' => '',
    'Maximum allowed age for logs.' => '',
    'Maximum upload file size (in MB)' => '',
    'Mobile appearance' => '',
    'Name of the application' => '',
    'No Delivery (Debug Mode, Save as file)' => '',
    'No Proxy Hosts' => '',
    'No caching' => '',
    'Notification Settings' => '',
    'Old logs can significantly increase the size of your database while providing little information.' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'PHP (Use settings of php.ini file)' => '',
    'PHP APC(u) Extension missing - Type not available!' => '',
    'PHP reported a maximum of {maxUploadSize} MB' => '',
    'Password' => '',
    'Port' => '',
    'Port number' => '',
    'Prevent client caching of following scripts' => '',
    'Provider Name' => '',
    'Redis' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Save' => '',
    'Save & Flush Caches' => '',
    'Save & Test' => '',
    'Saved' => '',
    'Saved and flushed cache' => '',
    'Saved and sent test email to: {address}' => '',
    'Server' => '',
    'Show introduction tour for new users' => '',
    'Show user profile post form on dashboard' => '',
    'Sort by creation date' => '',
    'Sort by update date' => '',
    'Test message' => '',
    'Theme' => '',
    'These settings refer to advanced topics of your social network.' => '',
    'These settings refer to the appearance of your social network.' => '',
    'Topic has been deleted!' => '',
    'Topics' => '',
    'Url Pattern' => '',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => '',
    'Use SMTPS' => '',
    'Use X-Sendfile for File Downloads' => '',
    'User Display Name' => '',
    'User Display Name Subtitle' => '',
    'User Settings' => '',
    'Username' => '',
    'Username (e.g. john)' => '',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => '',
    'You can find more configuration options here:' => '',
    'You\'re using no icon at the moment. Upload your logo now.' => '',
    'You\'re using no logo at the moment. Upload your logo now.' => '',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => '',
    'e.g. localhost' => '',
    'e.g. smtps://user:pass@smtp.example.com:port' => '',
    'never' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/uz/settings.php <==
<?php

return [
    'User' => 'Foydalanuvchi',
    '"My Spaces" Sorting' => '',
    '1 month' => '',
    '1 week' => '',
    '1 year' => '',
    '2 weeks' => '',
    '3 months' => '',
    '6 months' => '',
    '<strong>Confirm</strong> icon deletion' => '',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Confirm</strong> topic deletion' => '',
    '<strong>Mobile App</strong> Debug Page' => '',
    'A dedicated image can be uploaded in the Appearance admin page.' => '',
    'Accent color' => '',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Add OEmbed provider' => '',
    'Add Topic' => '',
    'Add custom info text for maintenance mode. Displayed on the login page.' => '',
    'Add individual info text...' => '',
    'Add new provider' => '',
    'Advanced Settings' => '',
    'Allow Self-Signed Certificates?' => '',
    'Allow establishing verified connections with the mobile app to enable Android app links and iOS universal links and redirect web content to the mobile app.' => '',
    'Allowed file extensions' => '',
    'Appearance Settings' => '',
    'Auto format based on user language - Example: {example}' => '',
    'Back to overview' => '',
    'Base URL' => '',
    'Caches flushed successfully' => '',
    'Cannot compile SCSS to CSS:' => '',
    'Comma separated list. Leave empty to allow all.' => '',
    'Configuration (Use settings from configuration file)' => '',
    'Convert to global topic' => '',
    'Could not send test email.' => '',
    'Currently no provider active!' => '',
    'Currently there are {count} records in the database dating from {dating}.' => '',
    'Custom DSN' => '',
    'Custom SCSS' => '',
    'Custom sort order (alphabetical if not defined)' => '',
    'Custom sort order can be defined in the Space advanced settings.' => '',
    'DSN' => '',
    'DSN Examples:' => '',
    'Danger color' => '',
    'Dark color' => '',
    'Dashboard' => '',
    'Date input format' => '',
    'Debug' => '',
    'Default' => '',
    'Default Timezone' => '',
    'Default language' => '',
    'Default pagination size (Entries per page)' => '',
    'Default stream content order' => '',
    'Delete' => '',
    'Do you really want to delete this topic?' => '',
    'Domain URLs to whitelist, separated by comma' => '',
    'E-Mail' => '',
    'E-Mail reply-to' => '',
    'E-Mail sender address' => '',
    'E-Mail sender name' => '',
    'E.g. URLs of the SSO service providers' => '',
    'E.g. http://example.com/humhub' => '',
    'Edit OEmbed provider' => '',
    'Email Header Image' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Enable Link Redirection Service' => '',
    'Enable maintenance mode' => '',
    'Enable user friendship system' => '',
    'Enabled' => '',
    'Enabled OEmbed providers' => '',
    'Endpoint Url' => '',
    'Exclude media files from stream attachment list' => '',
    'Firstname Lastname (e.g. John Doe)' => '',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => '',
    'Flush Caches' => '',
    'Friendship' => '',
    'General' => '',
    'General Settings' => '',
    'Global topics can be used by all users in all Spaces. They make it easier for you to define consistent keywords throughout your entire network. If users have already created topics in Spaces, you can also convert them to global topics here.' => '',
    'HTML tracking code' => '',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => '',
    'Here you can configure basic settings of your social network.' => '',
    'Icon upload' => '',
    'In order for links to open in the app on mobile devices, rather than in the mobile browser, all links (e.g. notification emails) need to be routed through the HumHub proxy server.' => '',
    'Info color' => '',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
    'Invalid URL format: {domain}' => '',
    'Last visit' => '',
    'Light color' => '',
    'Login Background' => '',
    'Logo upload' => '',
    'Mail Transport Type' => '',
    'Maintenance mode' => '',
    'Maintenance mode restricts access to the platform and immediately logs out all users except Admins.' => '',
    'Maximum allowed age for logs.' => '',
    'Maximum upload file size (in MB)' => '',
    'Mobile App' => '',
    'Name of the application' => '',
    'No Delivery (Debug Mode, Save as file)' => '',
    'No Proxy Hosts' => '',
    'Notification Settings' => '',
    'Old logs can significantly increase the size of your database while providing little information.' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'PHP (Use settings of php.ini file)' => '',
    'PHP reported a maximum of {maxUploadSize} MB' => '',
    'Password' => '',
    'Please enable <a href="{url}" target="_blank">Pretty URLs</a> for proper working of the well-known files.' => '',
    'Port' => '',
    'Port number' => '',
    'Primary color' => '',
    'Provider Name' => '',
    'Recommended minimum height: {recommendedMinHeight}px (minimum {minWidth} x {minHeight} px).' => '',
    'Recommended size: {recommendedWidth} × {recommendedHeight}px (minimum {minWidth} x {minHeight} px).' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Save' => '',
    'Save & Test' => '',
    'Saved and sent test email to: {address}' => '',
    'Secondary color' => '',
    'Server' => '',
    'Show introduction tour for new users' => '',
    'Show network name instead of logo in email header' => '',
    'Show user profile post form on dashboard' => '',
    'Sort by creation date' => '',
    'Sort by update date' => '',
    'Success color' => '',
    'Test message' => '',
    'Theme' => '',
    'Theme customization' => '',
    'These settings refer to advanced topics of your social network.' => '',
    'These settings refer to the appearance of your social network.' => '',
    'Topic has been deleted!' => '',
    'Topics' => '',
    'URL to the file {fileNameLink}' => '',
    'Url Pattern' => '',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => '',
    'Use SMTPS' => '',
    'Use Sassy CSS syntax (SCSS)' => '',
    'Use X-Sendfile for File Downloads' => '',
    'User Display Name' => '',
    'User Display Name Subtitle' => '',
    'User Settings' => '',
    'Username' => '',
    'Username (e.g. john)' => '',
    'Warning color' => '',
    'Well-known file {fileName}' => '',
    'Well-known files' => '',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => '',
    'You can find more configuration options here:' => '',
    'You\'re using no icon at the moment. Upload your logo now.' => '',
    'You\'re using no logo at the moment. Upload your logo now.' => '',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => '',
    'e.g. localhost' => '',
    'e.g. smtps://user:pass@smtp.example.com:port' => '',
    'never' => '',
];
